/*
 * Raima Database Manager
 *
 * Copyright (C) 2016 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 */

/** \file pspplatos.h
 *  \brief Header for the Platform Support Package - Dependent settings for each OS
 *
 *  The content of this file is for the most part only applicable when
 *  compiling using an RDM source package or an engineering build.  It
 *  is defines for the platform support package.
 *
 *  Regarding an object package this is provided here for your
 *  information.
 */

#include "pspplatcpu.h"

#if !defined(PSPPLATOS_H_INCLUDED_)
#define PSPPLATOS_H_INCLUDED_

#if defined(RDM_DOXYGEN)
/** Have alloca (may be defined on some OS) */
#define RDM_ALLOCA_HAVE_ALLOCA
#undef RDM_ALLOCA_HAVE_ALLOCA

/** Have malloc.h that declares alloca (may be defined on some OS) */
#define RDM_ALLOCA_HAVE_MALLOC_H_WITH_ALLOCA
#undef RDM_ALLOCA_HAVE_MALLOC_H_WITH_ALLOCA

/** Have variable size arrays (may be defined on some OS) */
#define RDM_ALLOCA_HAVE_VARIABLE_SIZE_ARRAY
#undef RDM_ALLOCA_HAVE_VARIABLE_SIZE_ARRAY

/** Implement assert using an infinite loop (may be defined on some OS) */
#define RDM_ASSERT_INFINITE_LOOP
#undef RDM_ASSERT_INFINITE_LOOP

/** Atomic integer implementation for Integrity (may be defined on some OS) */
#define RDM_ATOMIC_INTEGRITY
#undef RDM_ATOMIC_INTEGRITY

/** No atomic integer implementation (may be defined on some OS) */
#define RDM_ATOMIC_NO
#undef RDM_ATOMIC_NO

/** Atomic integer implementation for Unix (may be defined on some OS) */
#define RDM_ATOMIC_UNIX
#undef RDM_ATOMIC_UNIX

/** Atomic integer implementation for Windows (may be defined on some OS) */
#define RDM_ATOMIC_WINDOWS
#undef RDM_ATOMIC_WINDOWS

/** No implementation for string collate (may be defined on some OS) */
#define RDM_COLLATE_NO
#undef RDM_COLLATE_NO

/** Have reentrant versions of collate (may be defined on some OS) */
#define RDM_COLLATE_REENTRANT
#undef RDM_COLLATE_REENTRANT

/** Unix implementation for string collate (may be defined on some OS) */
#define RDM_COLLATE_UNIX
#undef RDM_COLLATE_UNIX

/** Windows implementation for string collate (may be defined on some OS) */
#define RDM_COLLATE_WINDOWS
#undef RDM_COLLATE_WINDOWS

/** Do not invode the C preprocessor for input file to rdm-convert (may be defined on some OS) */
#define RDM_CONVERT_NO_PREPRO
#undef RDM_CONVERT_NO_PREPRO

/** Have C++ standard String class (may be defined on some OS) */
#define RDM_CPP_HAVE_STD_STRING
#undef RDM_CPP_HAVE_STD_STRING

/** No Daemon implementation (may be defined on some OS) */
#define RDM_DAEMON_NO
#undef RDM_DAEMON_NO

/** Daemon implementation for Unix (may be defined on some OS) */
#define RDM_DAEMON_UNIX
#undef RDM_DAEMON_UNIX

/** Have getifaddrs (may be defined on some OS) */
#define RDM_ENV_HAVE_GETIFADDRS
#undef RDM_ENV_HAVE_GETIFADDRS

/** No environment implementation (may be defined on some OS) */
#define RDM_ENV_NO
#undef RDM_ENV_NO

/** Envirionment implementation for Linux (may be defined on some OS) */
#define RDM_ENV_LINUX
#undef RDM_ENV_LINUX

/** Envirionment implementation for macOS (may be defined on some OS) */
#define RDM_ENV_OSX
#undef RDM_ENV_OSX

/** Envirionment implementation for Unix (may be defined on some OS) */
#define RDM_ENV_UNIX
#undef RDM_ENV_UNIX

/** Envirionment implementation for Vxworks Kernel modules (may be defined on some OS) */
#define RDM_ENV_VXWORKS
#undef RDM_ENV_VXWORKS

/** Envirionment implementation for Vxworks RTP (may be defined on some OS) */
#define RDM_ENV_VXWORKS_RTP
#undef RDM_ENV_VXWORKS_RTP

/** Envirionment implementation for Windows (may be defined on some OS) */
#define RDM_ENV_WINDOWS
#undef RDM_ENV_WINDOWS

/** Define _CRT_NONSTDC_NO_DEPRECATE (may be defined on some OS) */
#define RDM_FEATURES_CRT_NONSTDC_NO_DEPRECATE
#undef RDM_FEATURES_CRT_NONSTDC_NO_DEPRECATE

/** Define _CRT_SECURE_NO_DEPRECATE (may be defined on some OS) */
#define RDM_FEATURES_CRT_SECURE_NO_DEPRECATE
#undef RDM_FEATURES_CRT_SECURE_NO_DEPRECATE

/** Define _CRT_SECURE_NO_WARNINGS (may be defined on some OS) */
#define RDM_FEATURES_CRT_SECURE_NO_WARNINGS
#undef RDM_FEATURES_CRT_SECURE_NO_WARNINGS

/** Define _GNU_SOURCE (may be defined on some OS) */
#define RDM_FEATURES_GNU_SOURCE
#undef RDM_FEATURES_GNU_SOURCE

/** Define _POSIX_C_SOURCE to the specified value (may be defined on some OS) */
#define RDM_FEATURES_POSIX_C_SOURCE
#undef RDM_FEATURES_POSIX_C_SOURCE

/** Define _REENTRANT (may be defined on some OS) */
#define RDM_FEATURES_REENTRANT
#undef RDM_FEATURES_REENTRANT

/** Define RW_MULTI_THREAD (may be defined on some OS) */
#define RDM_FEATURES_RW_MULTI_THREAD
#undef RDM_FEATURES_RW_MULTI_THREAD

/** Define __EXTENSIONS__ (may be defined on some OS) */
#define RDM_FEATURES__EXTENSIONS__
#undef RDM_FEATURES__EXTENSIONS__

/** Have the capability of syncing a directory (may be defined on some OS) */
#define RDM_FILE_HAVE_DIR_SYNC
#undef RDM_FILE_HAVE_DIR_SYNC

/** Have fallocate for punching holes in files (may be defined on some OS) */
#define RDM_FILE_HAVE_FALLOCATE
#undef RDM_FILE_HAVE_FALLOCATE

/** Have flock for doing file locking (may be defined on some OS) */
#define RDM_FILE_HAVE_FLOCK
#undef RDM_FILE_HAVE_FLOCK

/** Have lockf for doing file locking (may be defined on some OS) */
#define RDM_FILE_HAVE_LOCKF
#undef RDM_FILE_HAVE_LOCKF

/** Have posix_fadvise for paging out pages in the file cache (may be defined on some OS) */
#define RDM_FILE_HAVE_POSIX_FADVISE
#undef RDM_FILE_HAVE_POSIX_FADVISE

/** Have pread and pwrite (may be defined on some OS) */
#define RDM_FILE_HAVE_PREAD
#undef RDM_FILE_HAVE_PREAD

/** No file locking (may be defined on some OS) */
#define RDM_FILE_LOCK_NO
#undef RDM_FILE_LOCK_NO

/** No file system implementation for unbuffered read and write and other file
 * operations (may be defined on some OS) */
#define RDM_FILE_NO
#undef RDM_FILE_NO

/** Reliance Edge file system from Datalight */
#define RDM_FILE_RED
#undef RDM_FILE_RED

/** Reading and writing of buffered files using stdio.  No other file operations
 * (may be defined on some OS) */
#define RDM_FILE_STDIO
#undef RDM_FILE_STDIO

/** Unix file system implementation for unbuffered read and write and other file
 * operations (may be defined on some OS) */
#define RDM_FILE_UNIX
#undef RDM_FILE_UNIX

/** Windows file system implementation for unbuffered read and write and other
 * file operations (may be defined on some OS) */
#define RDM_FILE_WINDOWS
#undef RDM_FILE_WINDOWS

/** Use bitmasks for determining IEEE-754 INF and NAN (may be defined on some OS) */
#define RDM_FLOAT_BITMASKS_FOR_ISFINITE_AND_ISN
#undef RDM_FLOAT_BITMASKS_FOR_ISFINITE_AND_ISN

/** Have floorf and ceilf (may be defined on some OS) */
#define RDM_FLOAT_HAVE_FLOORF
#undef RDM_FLOAT_HAVE_FLOORF

/** Have isfinite and isnan (may be defined on some OS) */
#define RDM_FLOAT_HAVE_ISFINITE
#undef RDM_FLOAT_HAVE_ISFINITE

/** Shared memory (may be defined on some OS) */
#define RDM_HAS_SHARED_MEMORY
#undef RDM_HAS_SHARED_MEMORY

/** A platform independent logging implementation (may be defined on some OS) */
#define RDM_LOGGING
#undef RDM_LOGGING

/** No logging implementation (may be defined on some OS) */
#define RDM_LOGGING_NO
#undef RDM_LOGGING_NO

/** Use GCC builtin for floatingoint constants */
#define RDM_MATH_GCC_BUILTIN
#undef RDM_MATH_GCC_BUILTIN

/** Get floatingoint constants from values.h */
#define RDM_MATH_CONST_VALUES_H
#undef RDM_MATH_CONST_VALUES_H

/** Get floatingoint constants from float.h */
#define RDM_MATH_CONST_FLOAT_H
#undef RDM_MATH_CONST_FLOAT_H

/** Dynamic memory allocated is 4K aligned  (may be defined on some OS) */
#define RDM_MEM_ALIGN_4K
#undef RDM_MEM_ALIGN_4K

/** Dynamic memory allocation using malloc and request large blocks (may be defined on some OS) */
#define RDM_MEM_MALLOC
#undef RDM_MEM_MALLOC

/** Dynamic memory allocation using mmap on Unix and request large blocks (may be defined on some OS) */
#define RDM_MEM_MMAP
#undef RDM_MEM_MMAP

/** Dynamic memory allocation using memalign/free on VxWorks and request large blocks (may be defined on some OS) */
#define RDM_MEM_VXWORKS
#undef RDM_MEM_VXWORKS

/** No dynamic memory allocation (may be defined on some OS) */
#define RDM_MEM_NO
#undef RDM_MEM_NO

/** Use a buffer of this size when allocating memory statically (may be defined on some OS) */
#define RDM_MEM_STATIC_SIZE
#undef RDM_MEM_STATIC_SIZE

/** Dynamic memory allocation using virtual_alloc on Windows and request large
 * blocks (may be defined on some OS) */
#define RDM_MEM_VIRTUAL_ALLOC
#undef RDM_MEM_VIRTUAL_ALLOC

/** Have strcasecmp (may be defined on some OS) */
#define RDM_STR_HAVE_STRCASECMP
#undef RDM_STR_HAVE_STRCASECMP

/** Have strcasestr (may be defined on some OS) */
#define RDM_STR_HAVE_STRCASESTR
#undef RDM_STR_HAVE_STRCASESTR

/** Have strncasecmp (may be defined on some OS) */
#define RDM_STR_HAVE_STRNCASECMP
#undef RDM_STR_HAVE_STRNCASECMP

/** Have strncmp (may be defined on some OS) */
#define RDM_STR_HAVE_STRNCMP
#undef RDM_STR_HAVE_STRNCMP

/** Have strtoll and strtoull (may be defined on some OS) */
#define RDM_STR_HAVE_STRTOLL
#undef RDM_STR_HAVE_STRTOLL

/** Have strupr and strlwr (may be defined on some OS) */
#define RDM_STR_HAVE_STRUPR
#undef RDM_STR_HAVE_STRUPR

/** Have ffsll for finding the first bit set in a word (may be defined on some OS) */
#define RDM_TAG_HAVE_FFSLL
#undef RDM_TAG_HAVE_FFSLL

/**We have a TCP implementation (may be defined on some OS) */
#define RDM_TCP
#undef RDM_TCP

/** Implement a TCP transport (may be defined on some OS) */
#define RDM_TCP
#undef RDM_TCP

/** Use socket option TCP_NODELAY for accepting a connection (may be defined on some OS) */
#define RDM_TCP_ACCEPT_NO_DELAY
#undef RDM_TCP_ACCEPT_NO_DELAY

/** Use socket option TCP_NODELAY for conneting (may be defined on some OS) */
#define RDM_TCP_CONNECT_NO_DELAY
#undef RDM_TCP_CONNECT_NO_DELAY

/** Use socket option SO_KEEPALIVE (may be defined on some OS) */
#define RDM_TCP_DONT_USE_KEEPALIVES
#undef RDM_TCP_DONT_USE_KEEPALIVES

/** Have the send flag MSG_NOSIGNAL (may be defined on some OS) */
#define RDM_TCP_HAVE_MSG_NOSIGNAL
#undef RDM_TCP_HAVE_MSG_NOSIGNAL

/** Have poll and use this instead of select (may be defined on some OS) */
#define RDM_TCP_HAVE_POLL
#undef RDM_TCP_HAVE_POLL

/** Have Quality Of Service (may be defined on some OS) */
#define RDM_TCP_HAVE_QOS
#undef RDM_TCP_HAVE_QOS

/** The IP address to use for localhost (may be defined on some OS) */
#define RDM_TCP_LOCALHOST "127.0.0.1"
#undef RDM_TCP_LOCALHOST

/** No IP version 6 implementation (may be defined on some OS) */
#define RDM_TCP_NO_IPV6
#undef RDM_TCP_NO_IPV6

/** Thread priority levels are derived from this and RDM_THREAD_INC_PRIORITY (may be defined on some OS) */
#define RDM_THREAD_BASE_PRIORITY
#undef RDM_THREAD_BASE_PRIORITY

/** Thread implemantation for FreeRTOS */
#define RDM_THREAD_FREE_RTOS
#undef RDM_THREAD_FREE_RTOS

/** Thread priority levels are derived from this and RDM_THREAD_BASE_PRIORITY (may be defined on some OS) */
#define RDM_THREAD_INC_PRIORITY
#undef RDM_THREAD_INC_PRIORITY

/** Thread implementation for INTEGRITY (may be defined on some OS) */
#define RDM_THREAD_INTEGRITY
#undef RDM_THREAD_INTEGRITY

/** No thread implementation (may be defined on some OS) */
#define RDM_THREAD_NO
#undef RDM_THREAD_NO

/** Thread implementation for Posix Threads on Unix (may be defined on some OS) */
#define RDM_THREAD_PTHREAD
#undef RDM_THREAD_PTHREAD

/** Thread implementation for VxWorks (may be defined on some OS) */
#define RDM_THREAD_VXWORKS
#undef RDM_THREAD_VXWORKS

/** Thread implementation for Windows (may be defined on some OS) */
#define RDM_THREAD_WINDOWS
#undef RDM_THREAD_WINDOWS

/** Use clock ticks for FREE_RTOS to measure elapsed time */
#define RDM_TIME_FREE_RTOS
#undef RDM_TIME_FREE_RTOS

/** Have clock_gettime (may be defined on some OS) */
#define RDM_TIME_HAVE_CLOCK_GETTIME
#undef RDM_TIME_HAVE_CLOCK_GETTIME

/** Have the time64_t type (may be defined on some OS) */
#define RDM_TIME_HAVE_TIME64_T
#undef RDM_TIME_HAVE_TIME64_T

/** No time implementation (may be defined on some OS) */
#define RDM_TIME_NO
#undef RDM_TIME_NO

/** Timed implementation for Unix (may be defined on some OS) */
#define RDM_TIME_UNIX
#undef RDM_TIME_UNIX

/** Time implementation for Windows (may be defined on some OS) */
#define RDM_TIME_WINDOWS
#undef RDM_TIME_WINDOWS

/** Windows UNICODE handling (may be defined on some OS) */
#define RDM_UNICODE
#undef RDM_UNICODE

/** This is a Posix or Unix like system (may be defined on some OS) */
#define RDM_UNIX
#undef RDM_UNIX

/** Have va_copy (may be defined on some OS) */
#define RDM_VARARGS_HAVE_VA_COPY
#undef RDM_VARARGS_HAVE_VA_COPY

/** Using our own vsnprintf (may be defined on some OS) */
#define RDM_VSNPRINTF
#undef RDM_VSNPRINTF

/** Use strtok_r implementation
 *
 *  Note: strtok will be used if RDM_THREAD_NO is defined and neither
 *  RDM_HAVE_STRTOK_S nor RDM_HAVE_STRTOK_R is defined. Use of strtok
 *  from more than one thread without proper protection is not safe.
 */
#define RDM_HAVE_STRTOK_R
#undef RDM_HAVE_STRTOK_R

/** Use strtok_s implementation
 *
 *  Note: strtok will be used if RDM_THREAD_NO is defined and neither
 *  RDM_HAVE_STRTOK_S nor RDM_HAVE_STRTOK_R is defined. Use of strtok
 *  from more than one thread without proper protection is not safe.
 */
#define RDM_HAVE_STRTOK_S
#undef RDM_HAVE_STRTOK_S

/** Have an implementation of LZMA compression */
#define RDM_COMPRESS_HAVE_LZMA
#undef RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_LINUX)
#define RDM_ALLOCA_HAVE_VARIABLE_SIZE_ARRAY
#define RDM_ATOMIC_UNIX
#define RDM_COLLATE_REENTRANT
#define RDM_COLLATE_UNIX
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_UNIX
#define RDM_ENV_LINUX
#define RDM_FEATURES_GNU_SOURCE
#define RDM_FEATURES_REENTRANT
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_HAVE_FALLOCATE
#define RDM_FILE_HAVE_FLOCK
#define RDM_FILE_HAVE_POSIX_FADVISE
#define RDM_FILE_HAVE_PREAD
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_HAS_SHARED_MEMORY
#define RDM_HAVE_FORK
#define RDM_LOGGING
#define RDM_MATH_CONST_VALUES_H
#define RDM_MEM_ALIGN_4K
#define RDM_MEM_MMAP
#define RDM_STR_HAVE_STRCASECMP
#define RDM_STR_HAVE_STRCASESTR
#define RDM_STR_HAVE_STRNCASECMP
#define RDM_STR_HAVE_STRNCMP
#define RDM_TAG_HAVE_FFSLL
#define RDM_TCP
#define RDM_TCP_ACCEPT_NO_DELAY
#define RDM_TCP_HAVE_MSG_NOSIGNAL
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_HAVE_QOS
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_PTHREAD
#define RDM_TIME_HAVE_CLOCK_GETTIME
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_NEUTRINO)
#define RDM_ATOMIC_UNIX
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_UNIX
#define RDM_ENV_UNIX
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_HAVE_FLOCK
#define RDM_FILE_HAVE_PREAD
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_HAS_SHARED_MEMORY
#define RDM_LOGGING
#define RDM_MATH_CONST_FLOAT_H
#define RDM_STR_HAVE_STRCASECMP
#define RDM_STR_HAVE_STRNCASECMP
#define RDM_STR_HAVE_STRNCMP
#define RDM_TAG_HAVE_FFSLL
#define RDM_TCP
#define RDM_TCP_ACCEPT_NO_DELAY
#define RDM_TCP_HAVE_MSG_NOSIGNAL
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_HAVE_QOS
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_PTHREAD
#define RDM_TIME_HAVE_CLOCK_GETTIME
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_IPHONE)
#define RDM_ATOMIC_UNIX
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_UNIX
#define RDM_ENV_OSX
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_HAVE_FLOCK
#define RDM_FILE_HAVE_PREAD
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_LOGGING
#define RDM_MATH_CONST_FLOAT_H
#define RDM_STR_HAVE_STRCASECMP
#define RDM_STR_HAVE_STRCASESTR
#define RDM_STR_HAVE_STRNCASECMP
#define RDM_STR_HAVE_STRNCMP
#define RDM_TAG_HAVE_FFSLL
#define RDM_TCP
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_PTHREAD
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_OSX)
#define RDM_ATOMIC_UNIX
#define RDM_COLLATE_REENTRANT
#define RDM_COLLATE_UNIX
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_UNIX
#define RDM_ENV_OSX
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_HAVE_FLOCK
#define RDM_FILE_HAVE_PREAD
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_HAS_SHARED_MEMORY
#define RDM_LOGGING
#define RDM_MATH_CONST_FLOAT_H
#define RDM_MEM_ALIGN_4K
#define RDM_MEM_MMAP
#define RDM_STR_HAVE_STRCASECMP
#define RDM_STR_HAVE_STRCASESTR
#define RDM_STR_HAVE_STRNCASECMP
#define RDM_STR_HAVE_STRNCMP
#define RDM_TAG_HAVE_FFSLL
#define RDM_TCP
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_PTHREAD
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_SOLARIS)
#define RDM_ATOMIC_UNIX
#define RDM_COLLATE_NO
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_UNIX
#define RDM_ENV_UNIX
#define RDM_FEATURES_POSIX_C_SOURCE 200112
#define RDM_FEATURES__EXTENSIONS__
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_HAVE_LOCKF
#define RDM_FILE_HAVE_PREAD
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_HAS_SHARED_MEMORY
#define RDM_LOGGING
#define RDM_MATH_CONST_FLOAT_H
#define RDM_MEM_ALIGN_4K
#define RDM_MEM_MMAP
#define RDM_STR_HAVE_STRCASECMP
#define RDM_STR_HAVE_STRNCASECMP
#define RDM_STR_HAVE_STRNCMP
#define RDM_TCP
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_PTHREAD
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_WINDOWS)
#define RDM_HAVE_STRTOK_S
#define RDM_ALLOCA_HAVE_ALLOCA
#define RDM_ALLOCA_HAVE_MALLOC_H_WITH_ALLOCA
#define RDM_ATOMIC_WINDOWS
#define RDM_COLLATE_REENTRANT
#define RDM_COLLATE_WINDOWS
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_NO
#define RDM_ENV_WINDOWS
#define RDM_FEATURES_CRT_NONSTDC_NO_DEPRECATE
#define RDM_FEATURES_CRT_SECURE_NO_DEPRECATE
#define RDM_FEATURES_CRT_SECURE_NO_WARNINGS
#define RDM_FILE_WINDOWS
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_MATH_CONST_FLOAT_H
#define RDM_HAS_SHARED_MEMORY
#define RDM_LOGGING
#define RDM_MEM_ALIGN_4K
#define RDM_MEM_VIRTUAL_ALLOC
#define RDM_STR_HAVE_STRNCMP
#define RDM_STR_HAVE_STRUPR
#define RDM_TCP
#define RDM_TCP_CONNECT_NO_DELAY
#define RDM_TCP_DONT_USE_KEEPALIVES
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_WINDOWS
#define RDM_TIME_WINDOWS
#define RDM_UNICODE
#if (_MSC_VER > 1600)
#define RDM_VARARGS_HAVE_VA_COPY
#endif
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_VXWORKS_RTP)
#if defined(__DCC__)
#define RDM_ATOMIC_NO
#else
#define RDM_ATOMIC_UNIX
#endif
#define RDM_COLLATE_NO
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_NO
#define RDM_ENV_VXWORKS_RTP
#define RDM_FEATURES_REENTRANT
#define RDM_FEATURES_RW_MULTI_THREAD
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_LOCK_NO
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_LOGGING
#define RDM_MATH_CONST_FLOAT_H
#define RDM_MEM_ALIGN_4K
#define RDM_MEM_VXWORKS
#define RDM_STR_HAVE_STRNCMP
#define RDM_TCP
#define RDM_TCP_DONT_USE_KEEPALIVES
#define RDM_TCP_NO_IPV6
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_PTHREAD
#define RDM_TIME_HAVE_CLOCK_GETTIME
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_VXWORKS)
#define RDM_ATOMIC_NO
#define RDM_COLLATE_NO
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_NO
#define RDM_ENV_VXWORKS
#define RDM_FEATURES_REENTRANT
#define RDM_FEATURES_RW_MULTI_THREAD
#define RDM_FILE_LOCK_NO
#define RDM_FILE_UNIX
#define RDM_FLOAT_BITMASKS_FOR_ISFINITE_AND_ISNAN
#define RDM_LOGGING
#define RDM_MATH_CONST_FLOAT_H
#define RDM_MEM_ALIGN_4K
#define RDM_MEM_VXWORKS
#define RDM_TCP
#define RDM_TCP_DONT_USE_KEEPALIVES
#define RDM_TCP_NO_IPV6
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_THREAD_BASE_PRIORITY 120
#define RDM_THREAD_INC_PRIORITY -2
#define RDM_THREAD_VXWORKS
#define RDM_TIME_HAVE_CLOCK_GETTIME
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_INTEGRITY)
#define RDM_ATOMIC_INTEGRITY
#define RDM_CONVERT_NO_PREPRO
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_NO
#define RDM_FEATURES_REENTRANT
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_LOCK_NO
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_MATH_CONST_FLOAT_H
#define RDM_LOGGING
#define RDM_MEM_MALLOC
#define RDM_STR_HAVE_STRNCMP
#define RDM_TCP
#define RDM_TCP_HAVE_POLL
#define RDM_TCP_LOCALHOST "127.0.0.1"
#define RDM_THREAD_BASE_PRIORITY 127
#define RDM_THREAD_INTEGRITY
#define RDM_THREAD_PTHREAD
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_ANDROID)
#define RDM_ATOMIC_UNIX
#define RDM_COLLATE_NO
#define RDM_CPP_HAVE_STD_STRING
#define RDM_DAEMON_UNIX
#define RDM_ENV_LINUX
#define RDM_FEATURES_GNU_SOURCE
#define RDM_FEATURES_REENTRANT
#define RDM_FILE_HAVE_DIR_SYNC
#define RDM_FILE_HAVE_PREAD
#define RDM_FILE_UNIX
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_HAS_SHARED_MEMORY
#define RDM_LOGGING
#define RDM_MATH_CONST_VALUES_H
#define RDM_STR_HAVE_STRCASECMP
#define RDM_STR_HAVE_STRCASESTR
#define RDM_STR_HAVE_STRNCASECMP
#define RDM_STR_HAVE_STRNCMP
#define RDM_TCP
#define RDM_TCP_HAVE_MSG_NOSIGNAL
#define RDM_TCP_LOCALHOST "localhost"
#define RDM_TIME_UNIX
#define RDM_UNIX
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
#define RDM_COMPRESS_HAVE_LZMA

#elif defined(RDM_FREE_RTOS)
#define RDM_FEATURES_GNU_SOURCE
#define RDM_ALLOCA_HAVE_VARIABLE_SIZE_ARRAY
#define RDM_ASSERT_INFINITE_LOOP
#define RDM_ATOMIC_NO
#define RDM_COLLATE_NO
#define RDM_DAEMON_NO
#define RDM_ENV_NO
#define RDM_FILE_UNIX
#define RDM_FILE_LOCK_NO
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_LOGGING_NO
#define RDM_MATH_GCC_BUILTIN
#define RDM_MEM_MALLOC
#define RDM_THREAD_FREE_RTOS
#define RDM_TIME_FREE_RTOS
#define RDM_HAVE_STRTOK_R
#define RDM_VARARGS_HAVE_VA_COPY
  
#elif defined(RDM_NO_OS)
#define RDM_COMPRESS_HAVE_LZMA
#define RDM_ALLOCA_HAVE_ALLOCA
#if defined(_MSC_VER)
#define RDM_ALLOCA_HAVE_MALLOC_H_WITH_ALLOCA
#define RDM_MATH_CONST_FLOAT_H
#else
#define RDM_MATH_GCC_BUILTIN
#define RDM_FLOAT_HAVE_ISFINITE
#define RDM_VARARGS_HAVE_VA_COPY
#endif
#define RDM_ASSERT_INFINITE_LOOP
#define RDM_ATOMIC_NO
#define RDM_COLLATE_NO
#define RDM_DAEMON_NO
#define RDM_ENV_NO
#define RDM_FILE_NO
#define RDM_FILE_STDIO
#define RDM_FLOAT_HAVE_FLOORF
#define RDM_LOGGING_NO
#define RDM_MEM_NO
#define RDM_MEM_STATIC_SIZE 0x400000
#define RDM_THREAD_NO
#define RDM_TIME_NO
#else
#error No OS specific section found
#endif

#if defined(RDM_THREAD_NO)
#undef RDM_THREAD_FREE_RTOS
#undef RDM_THREAD_PTHREAD
#undef RDM_THREAD_WINDOWS
#undef RDM_THREAD_INTEGRITY
#undef RDM_THREAD_VXWORKS
#undef RDM_HAS_SHARED_MEMORY
#endif

#endif /* PSPPLATOS_H_INCLUDED_ */
